/*
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.parser;

/**
 * An implementation of <code>ElementFactory</code>.
 *
 * @version 19980206
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 */
public class DefaultElementFactory implements ElementFactory {
    /**
     * Make new <code>DefaultElementFactory</code> instance.
     */
    public DefaultElementFactory() {
    }

    /**
     * Create <code>TXElement</code> instance.
     */
    public TXElement createElement(String name) {
        return createElement(name, null, name);
    }

    /**
     * Create <code>TXElement</code> instance.
     */
    public TXElement createElement(String qname, String ns, String n) {
        return new TXElement(qname, ns, n);
    }

    /**
     * Call <code>TXElement#ripen()</code>.
     */
    public void ripenElement(TXElement el) {
        el.ripen();
    }

    /**
     * Create <code>TXText</code> instance.
     */
    public TXText createText(String data) {
        return createText(data, false);
    }
    /**
     * Create <code>TXText</code> instance.
     */
    public TXText createText(String data, boolean ignorable) {
        TXText te = new TXText(data);
        te.setIsIgnorableWhitespace(ignorable);
        return te;
    }

    /**
     * Create <code>TXCDATASection</code> instance.
     */
    public TXCDATASection createCDATA(String data) {
        return new TXCDATASection(data);
    }

    /**
     * Create <code>TXComment</code> instance.
     */
    public TXComment createComment(String data) {
        return new TXComment(data);
    }

    /**
     * Create <code>TXPI</code> instance.
     */
    public TXPI createPI(String name, String data) {
        return new TXPI(name, data);
    }

    /**
     * Create <code>TXDocument</code> instance.
     */
    public TXDocument createDocument() {
        return new TXDocument();
    }

    /**
     * Create <code>DTD</code> instance.
     */
    public DTD createDTD() {
        return new DTD();
    }

    /**
     * Create <code>DTD</code> instance.
     */
    public DTD createDTD(String rootname, ExternalID eid) {
        return new DTD(rootname, eid);
    }
}
